Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(128)

Unified Diff: media/audio/mac/audio_auhal_mac.h

Issue 2101303004: Pass delay and timestamp to AudioSourceCallback::OnMoreData. (Closed) Base URL: https://chromium.googlesource.com/chromium/src@master
Patch Set: Changes based on comments Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/audio/mac/audio_auhal_mac.h
diff --git a/media/audio/mac/audio_auhal_mac.h b/media/audio/mac/audio_auhal_mac.h
index b6f14f96093fb0dd239cecae9e280a51647978c3..7c68a6c9ab0b0267bf2e55544072999f121f954d 100644
--- a/media/audio/mac/audio_auhal_mac.h
+++ b/media/audio/mac/audio_auhal_mac.h
@@ -29,6 +29,7 @@
#include "base/macros.h"
#include "base/synchronization/lock.h"
#include "base/threading/thread_checker.h"
+#include "base/time/time.h"
#include "media/audio/audio_io.h"
#include "media/audio/audio_manager.h"
#include "media/base/audio_parameters.h"
@@ -131,8 +132,8 @@ class AUHALStream : public AudioOutputStream {
// if not available.
double GetHardwareLatency();
- // Gets the current playout latency value.
- double GetPlayoutLatency(const AudioTimeStamp* output_time_stamp);
+ // Gets the current target playout time.
+ base::TimeTicks GetTargetPlayoutTime(const AudioTimeStamp* output_time_stamp);
// Updates playout timestamp, current lost frames, and total lost frames and
// glitches.
@@ -191,8 +192,8 @@ class AUHALStream : public AudioOutputStream {
// sizes.
std::unique_ptr<AudioPullFifo> audio_fifo_;
- // Current buffer delay. Set by Render().
- uint32_t current_hardware_pending_bytes_;
+ // Current target playout time. Set by Render().
+ base::TimeTicks current_target_playout_time_;
// Lost frames not yet reported to the provider. Increased in
// UpdatePlayoutTimestamp() if any lost frame since last time. Forwarded to

Powered by Google App Engine
This is Rietveld 408576698